Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(260)

Unified Diff: Source/core/animation/ActiveAnimations.h

Issue 851693007: Prepare for responsive CSS animations. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Rebase Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/animation/ActiveAnimations.h
diff --git a/Source/core/animation/ActiveAnimations.h b/Source/core/animation/ActiveAnimations.h
index 02b52ab6f6bcd1a5c64bf8d64fde1716db64f843..39639da8be8c26d6002aa26c6724d1945754affa 100644
--- a/Source/core/animation/ActiveAnimations.h
+++ b/Source/core/animation/ActiveAnimations.h
@@ -96,8 +96,9 @@ private:
Vector<Animation*> m_animations;
#endif
// CSSAnimations checks if a style change is due to animation.
friend class CSSAnimations;
+ friend class DeferredLegacyStyleInterpolation;
};
} // namespace blink
@@ -96,8 +96,9 @@ private:
Vector<Animation*> m_animations;
#endif
- // CSSAnimations checks if a style change is due to animation.
+ // CSSAnimations and DeferredLegacyStyleInterpolation checks if a style change is due to animation.
friend class CSSAnimations;

Powered by Google App Engine
This is Rietveld 408576698